@@ -5,7 +5,7 @@ package Dancer2::Plugin::Path::Class;
 use strict;
 use warnings;
 
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 use Dancer2::Plugin;
 use MIME::Types;
@@ -68,7 +68,7 @@ sub _decorate_files {
 }
 
 register ls => sub {
-    my ($dsl, @args) = plugin_args(@_);
+    my ($dsl, @args) = @_;
     my $dir = dir(@args);
     my $ls_name = $dir->basename;
     my @dirs = ();
@@ -97,13 +97,13 @@ register ls => sub {
         $ls_files = _decorate_files($dir->parent, \@files);
     }
 
-    my $ls_cdup = $dsl->request->path;
+    my $ls_cdup = $dsl->app->request->path;
     $ls_cdup =~ s{/[^/]*$}{};
 
-    $dsl->var( ls_name  => $ls_name );
-    $dsl->var( ls_cdup  => $ls_cdup );
-    $dsl->var( ls_dirs  => $ls_dirs );
-    $dsl->var( ls_files => $ls_files );
+    $dsl->app->request->var( ls_name  => $ls_name );
+    $dsl->app->request->var( ls_cdup  => $ls_cdup );
+    $dsl->app->request->var( ls_dirs  => $ls_dirs );
+    $dsl->app->request->var( ls_files => $ls_files );
     
     return $dir;
 
